@@ -16,6 +16,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <ctype.h>
 
 
 #include "quotatool.h"
@@ -26,7 +27,7 @@
 
 
 #define WHITESPACE " \t\n"
-
+#define ABC "abcdefghijklmnopqrstuvwxyzABCDEFGHIJLKMNOPQRSTUVWXYZ"
 
 #if HAVE_GNU_GETOPT
 #  define OPTSTRING "hVvnu::g::birq:l:t:dR"
@@ -366,9 +367,12 @@ time_t parse_timespan (time_t orig, char *string)
   else if ( ! strncasecmp(cp, "mo", 2) ) {
     unit = MONTH;
   }
+  else if (strchr(ABC, *cp)) {
+     output_error ("Invalid format: %s", string);
+     return -1;
+  }
   else {
-    output_error ("Invalid format: %s", string);
-    return -1;
+     unit = SEC;
   }
 
   switch (op) {
